==> aptechka-0.42.1.tgz: package/lib/youtube/index.js <==
var L = (s) => {
  throw TypeError(s);
};
var b = (s, r, t) => r.has(s) || L("Cannot " + t);
var e = (s, r, t) => (b(s, r, "read from private field"), t ? t.call(s) : r.get(s)), o = (s, r, t) => r.has(s) ? L("Cannot add the same private member more than once") : r instanceof WeakSet ? r.add(s) : r.set(s, t), u = (s, r, t, a) => (b(s, r, "write to private field"), a ? a.call(s, t) : r.set(s, t), t), E = (s, r, t) => (b(s, r, "access private method"), t);
import { SourceElement as g } from "../source/index.js";
import "../window-resizer/index.js";
import "../Store-Cm3LPXlx.js";
import { d as v } from "../events-CsVF98U6.js";
import { g as T } from "../string-f0Dnk0L1.js";
var i, c, n, p, l, m, f, R, y, w;
const d = class d extends g {
  constructor() {
    super();
    o(this, y);
    o(this, i);
    o(this, c);
    o(this, n, !1);
    o(this, p, !1);
    o(this, l, () => {
      u(this, n, e(this, n) || this.hasAttribute("autoplay") && !this.hasAttribute("capture-autoplay")), u(this, i, new window.YT.Player(e(this, c), {
        playerVars: {
          mute: this.hasAttribute("muted") ? 1 : 0,
          controls: this.hasAttribute("controls") ? 1 : 0
        },
        events: {
          onReady: e(this, m),
          onError: e(this, f),
          onStateChange: e(this, R)
        }
      }));
    });
    o(this, m, () => {
      u(this, p, !0), E(this, y, w).call(this);
    });
    o(this, f, (t) => {
      var a, h;
      console.error("YouTube: Ошибка при загрузке видео:", this.currentURL, t), (h = (a = this.consumerElement).onerror) == null || h.call(a, new Event("error"));
    });
    o(this, R, () => {
    });
    u(this, c, "yt-" + T(10)), d.__apiReady || (window.onYouTubeIframeAPIReady = () => {
      d.__apiReady = !0, v(window, "youTubeIframeAPIReady");
    }), this.addEventListener("sourceCapture", () => {
      this.hasAttribute("capture-autoplay") && (e(this, p) ? e(this, i).playVideo() : u(this, n, !0));
    }), this.addEventListener("sourceRelease", () => {
      e(this, i) && this.hasAttribute("capture-autoplay") && (e(this, i).pauseVideo(), this.hasAttribute("replay") && e(this, i).seekTo(0));
    });
  }
  static __onYouTubeIframeAPIReady() {
    this.__apiReady = !0;
  }
  createConsumer() {
    const t = document.createElement("div");
    return t.id = e(this, c), t;
  }
  consumeSource(t) {
    var a;
    if (t) {
      if (!document.getElementById("youtube-script")) {
        const h = document.createElement("script");
        h.id, h.src = "https://www.youtube.com/iframe_api";
        const A = document.getElementsByTagName("script")[0];
        (a = A.parentNode) == null || a.insertBefore(h, A);
      }
      e(this, i) ? E(this, y, w).call(this) : d.__apiReady ? e(this, l).call(this) : addEventListener("youTubeIframeAPIReady", e(this, l));
    } else e(this, i) && e(this, i).stopVideo();
  }
  disconnectedCallback() {
    super.disconnectedCallback(), e(this, i) && e(this, i).destroy(), removeEventListener("youTubeIframeAPIReady", e(this, l));
  }
};
i = new WeakMap(), c = new WeakMap(), n = new WeakMap(), p = new WeakMap(), l = new WeakMap(), m = new WeakMap(), f = new WeakMap(), R = new WeakMap(), y = new WeakSet(), w = function() {
  var t, a;
  this.currentURL && (this.currentURL.startsWith("http") ? e(this, i).loadVideoByUrl(this.currentURL) : e(this, i).loadVideoById(this.currentURL)), e(this, n) ? e(this, i).playVideo() : e(this, i).stopVideo(), u(this, n, !1), (a = (t = this.consumerElement).onload) == null || a.call(t, new Event("load"));
}, d.__apiReady = !1;
let I = d;
customElements.get("e-youtube") || customElements.define("e-youtube", I);
export {
  I as YouTubeElement
};

==> aptechka-0.44.1.tgz: package/lib/youtube/index.js <==
var L = (s) => {
  throw TypeError(s);
};
var b = (s, r, t) => r.has(s) || L("Cannot " + t);
var e = (s, r, t) => (b(s, r, "read from private field"), t ? t.call(s) : r.get(s)), o = (s, r, t) => r.has(s) ? L("Cannot add the same private member more than once") : r instanceof WeakSet ? r.add(s) : r.set(s, t), u = (s, r, t, a) => (b(s, r, "write to private field"), a ? a.call(s, t) : r.set(s, t), t), E = (s, r, t) => (b(s, r, "access private method"), t);
import { SourceElement as g } from "../source/index.js";
import "../window-resizer/index.js";
import "../Store-D2xCXENW.js";
import { i as v } from "../index-euf5anj6.js";
import { d as T } from "../events-CsVF98U6.js";
import { g as V } from "../string-f0Dnk0L1.js";
var i, c, n, p, l, m, f, R, y, I;
const d = class d extends g {
  constructor() {
    super();
    o(this, y);
    o(this, i);
    o(this, c);
    o(this, n, !1);
    o(this, p, !1);
    o(this, l, () => {
      u(this, n, e(this, n) || this.hasAttribute("autoplay") && !this.hasAttribute("capture-autoplay")), u(this, i, new window.YT.Player(e(this, c), {
        playerVars: {
          mute: this.hasAttribute("muted") ? 1 : 0,
          controls: this.hasAttribute("controls") ? 1 : 0
        },
        events: {
          onReady: e(this, m),
          onError: e(this, f),
          onStateChange: e(this, R)
        }
      }));
    });
    o(this, m, () => {
      u(this, p, !0), E(this, y, I).call(this);
    });
    o(this, f, (t) => {
      var a, h;
      console.error("YouTube: Ошибка при загрузке видео:", this.currentURL, t), (h = (a = this.consumerElement).onerror) == null || h.call(a, new Event("error"));
    });
    o(this, R, () => {
    });
    u(this, c, "yt-" + V(10)), d.__apiReady || (window.onYouTubeIframeAPIReady = () => {
      d.__apiReady = !0, T(window, "youTubeIframeAPIReady");
    }), this.addEventListener("sourceCapture", () => {
      this.hasAttribute("capture-autoplay") && (e(this, p) ? e(this, i).playVideo() : u(this, n, !0));
    }), this.addEventListener("sourceRelease", () => {
      e(this, i) && this.hasAttribute("capture-autoplay") && (e(this, i).pauseVideo(), this.hasAttribute("replay") && e(this, i).seekTo(0));
    });
  }
  static __onYouTubeIframeAPIReady() {
    this.__apiReady = !0;
  }
  createConsumer() {
    const t = document.createElement("div");
    return t.id = e(this, c), t;
  }
  consumeSource(t) {
    var a;
    if (t) {
      if (!document.getElementById("youtube-script")) {
        const h = document.createElement("script");
        h.id, h.src = "https://www.youtube.com/iframe_api";
        const A = document.getElementsByTagName("script")[0];
        (a = A.parentNode) == null || a.insertBefore(h, A);
      }
      e(this, i) ? E(this, y, I).call(this) : d.__apiReady ? e(this, l).call(this) : addEventListener("youTubeIframeAPIReady", e(this, l));
    } else e(this, i) && e(this, i).stopVideo();
  }
  disconnectedCallback() {
    super.disconnectedCallback(), e(this, i) && e(this, i).destroy(), removeEventListener("youTubeIframeAPIReady", e(this, l));
  }
};
i = new WeakMap(), c = new WeakMap(), n = new WeakMap(), p = new WeakMap(), l = new WeakMap(), m = new WeakMap(), f = new WeakMap(), R = new WeakMap(), y = new WeakSet(), I = function() {
  var t, a;
  this.currentURL && (this.currentURL.startsWith("http") ? e(this, i).loadVideoByUrl(this.currentURL) : e(this, i).loadVideoById(this.currentURL)), e(this, n) ? e(this, i).playVideo() : e(this, i).stopVideo(), u(this, n, !1), (a = (t = this.consumerElement).onload) == null || a.call(t, new Event("load"));
}, d.__apiReady = !1;
let w = d;
v && !customElements.get("e-youtube") && customElements.define("e-youtube", w);
export {
  w as YouTubeElement
};
